@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -66,11 +66,11 @@ def play_music(music, tempo, patch, velocity):
         nl = 4
     else:
         bpm, nl = tempo
-    track = music_to_track(music, velocity)
-    track.prepend_bpm(bpm, nl)
-    for c in range(soundcard.synth.NUM_CHANNELS):
-        track.prepend_patch(c, patch)
-    soundcard.synth.play_track(track)
+    score = parser.parse_to_score_object(music)
+    tracklist = score.get_midi_events(velocity, None, None)
+    tracklist[0].prepend_bpm(bpm, nl)
+    [track.prepend_patch(patch) for track in tracklist]
+    soundcard.synth.play_track(*tracklist)
 
 ##################
 # midi functions #
