@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -418,48 +418,41 @@ class Score:
         kv.sort()
         if start is None and end is not None:
             return self._generate_midi_events(
-                     filter(lambda i, end=end: i < end, kv), velocity)
+                     filter(lambda i, end=end: i < end, kv), velocity,
+                     soundcard.Track)
         elif start is not None and end is None:
             return self._generate_midi_events(
-                     filter(lambda i, start=start: i >= start, kv), velocity)
+                     filter(lambda i, start=start: i >= start, kv), velocity,
+                     soundcard.Track)
         elif start is None and end is None:
-            return self._generate_midi_events(kv, velocity)
+            return self._generate_midi_events(kv, velocity, soundcard.Track)
         else:
             assert start is not None and end is not None
             return self._generate_midi_events(
-               filter(lambda i, start=start, end=end: start <= i < end, kv), velocity)
+               filter(lambda i, start=start, end=end: start <= i < end, kv), velocity,
+               soundcard.Track)
     def get_first_beat_midi_events(self):
         kv = self.m_timeposdict.keys()
         kv.sort()
-        return self._generate_midi_events([kv[0]], velocity)
+        return self._generate_midi_events([kv[0]], velocity, soundcard.Track)
     def get_last_beat_midi_events(self):
         kv = self.m_timeposdict.keys()
         kv.sort()
-        return self._generate_midi_events([kv[-1]], velocity)
-    def get_midi_events_with_channel(self, chan, velocity):
-        """Same as get_midi_events, but all voices will use channel chan.
-        This is used by the rhythm exercise.
-        """
+        return self._generate_midi_events([kv[-1]], velocity, soundcard.Track)
+    def get_midi_events_as_percussion(self, velocity):
         kv = self.m_timeposdict.keys()
         kv.sort()
-        track_list = []
-        for staff in self.m_staffs:
-            for voice in staff.m_voice_list:
-                track_list.append(voice.generate_track_for_voice(staff, kv, chan, velocity))
-        return track_list
-
-    def _generate_midi_events(self, kv, velocity):
+        return self._generate_midi_events(kv, velocity, soundcard.PercussionTrack)
+    def _generate_midi_events(self, kv, velocity, tracktype):
         """
-        kv is a list of rat.Rat that represent the timepos of columns
-        
+        kv is a list of rat.Rat that tell the timepos for all the tones
+        we should generate midi events for.
         Return a list of tracks, one track for each voice.
         """
         track_list = []
-        chan = 0
         for staff in self.m_staffs:
             for voice in staff.m_voice_list:
-                track_list.append(voice.generate_track_for_voice(staff, kv, chan, velocity))
-                chan = chan + 1
+                track_list.append(voice.generate_track_for_voice(staff, kv, velocity, tracktype))
         return track_list
 
 
@@ -589,7 +582,7 @@ class Voice:
                        # need these to generate midi track
                        self.m_coldict[pos1].m_music[p],
                        self.m_coldict[pos2].m_music[p]))
-    def generate_track_for_voice(self, staff, kv, chan, velocity):
+    def generate_track_for_voice(self, staff, kv, velocity, tracktype):
         # first we find the id()'s of music to tie
         tie_from_v = []
         tie_to_v = []
@@ -630,26 +623,26 @@ class Voice:
                         D[stop_pos].append((i, const.STOP_NOTE, n.m_pitch.semitone_pitch()))
                         i = i + 1
             last_timepos = coltimepos
-        return self.__gen_midi_last_step(D, chan, velocity)
-    def __gen_midi_last_step(self, D, chan, velocity):
+        return self.__gen_midi_last_step(D, velocity, tracktype)
+    def __gen_midi_last_step(self, D, velocity, tracktype):
         keys = D.keys()
         keys.sort()
         prev_time = Rat(0)
-        ms = soundcard.Track()
+        ms = tracktype()
         for k in keys:
             delta = None
             if k != Rat(0, 1):
-                delta = 1/(k-prev_time)
+                delta = k-prev_time
             prev_time = k
             for e in D[k]:
                 if e[1] == const.START_NOTE:
                     if delta:
                         ms.notelen_time(delta)
-                    ms.start_note(chan, e[2], velocity)
+                    ms.start_note(e[2], velocity)
                 elif e[1] == const.STOP_NOTE:
                     if delta:
                         ms.notelen_time(delta)
-                    ms.stop_note(chan, e[2], velocity)
+                    ms.stop_note(e[2], velocity)
                 delta = None
         return ms
 
