@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ soundcard.initialise_external_midiplayer(....)
 soundard.play_wav_file = play_wav
 """
 import sys
-from track import Track
+from track import Track, PercussionTrack
 from soundcardexceptions import SoundInitException
 synth = None
 
@@ -78,17 +78,23 @@ def initialise_using_fake_synth(verbose_init=None):
     import fakesynth
     synth = fakesynth.Synth(verbose_init)
 
-def play_note(patch, notelen, chan, pitch, vel=64):
+def play_note(patch, notelen, pitch, vel=64):
     assert isinstance(patch, int) and 0 <= patch < 128
     assert isinstance(notelen, int)
-    assert isinstance(chan, int) and 0 <= chan < 16
     assert isinstance(pitch, int) and 0 <= pitch < 128
     assert isinstance(vel, int) and 0 <= vel < 128
     m = Track()
-    m.set_patch(0, patch)
-    m.note(notelen, chan, pitch, vel)
+    m.set_patch(patch)
+    m.note(notelen, pitch, vel)
     synth.play_track(m)
 
+def play_perc(notelen, pitch, vel):
+    assert isinstance(notelen, int)
+    assert isinstance(pitch, int) and 0 <= pitch < 128
+    assert isinstance(vel, int) and 0 <= vel < 128
+    m = PercussionTrack()
+    m.note(notelen, pitch, vel)
+    synth.play_track(m)
 
 instrument_sections = (
     'piano',
