@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,10 +24,10 @@ class Synth:
         pass
     def stop(self):
         pass
-    def play_track(self, track):
-        print "FakeSynth.play_track(%s)" % track
+    def play_track(self, eventstream):
+        print "FakeSynth.play_track(%s)" % eventstream
         last = None
-        for e in track.m_v:
+        for e in eventstream:
             if e[0] != last:
                 print
             print e,
