@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -60,10 +60,10 @@ MIDI_PROGRAM_CHANGE = 0xc0
 
 def mf_tempo(n):
     """
-    number of microseconds per quarter note
+    n -- number of quarter tones per minute.
     """
+    #    now          Code to set tempo
     v = mf_delta(0) + [0xff, 0x51, 0x03] + mf_int24(int(500000*120/n))
-    #mf_int24(v, n*100000)#0x07a120)#, 0x07, 0xa1, 0x20] # 0.5 sec per quarter note
     return v
 
 def mf_timesig(numerator, denuminator):
@@ -91,16 +91,25 @@ def write_vect(f, v):
         f.write(chr(c))
 
 class MThd:
+    PPQN = 96
     def __init__(self, f):
         v = []
-        # format
+        # MIDI file format:
+        # 0: the file contains one single track containing midi data on
+        #    possibly all 16 midi channels
+        # 1: the file contains one or more simultaneous (ie, all start
+        #    from an assumed time of 0) tracks, perhaps each on a single
+        #    midi channel.
+        # 2: the file contains one or more sequentially independant
+        #    single-track patterns.
+        # We will use format 1.
         v = v + mf_int16(1)
+        # How many tracks are stored in the file.
         v = v + mf_int16(1)
-        v = v + mf_int16(0x00f0)#78)#f0)
-        #v = v + mf_int16(0xE728)
-              #who many Pulces (i.e. clocks) Per Quarter Note PPQN  or from
-              # another source: each increment of delta time represent
-        f.write("MThd") 
+        # Wow many Pulses (i.e. clocks) Per Quarter Note resolution
+        # the time-stamps are based upon.
+        v = v + mf_int16(MThd.PPQN)
+        f.write("MThd")
         write_int32(f, len(v)) #chunk len
         write_vect(f, v)
         
@@ -112,7 +121,8 @@ if __name__ == "__main__":
     d = MThd(f)
     v = []
     #v = v + mf_timesig(4, 4)
-    #v = v + mf_tempo(500000)
+    # Not really necessary, since this tempo is the default
+    v = v + mf_tempo(120)
     v = v + mf_program_change(0, 0)
     v = v + mf_program_change(1, 0)
     v = v + mf_program_change(2, 0)
@@ -127,6 +137,6 @@ if __name__ == "__main__":
     write_int32(f, len(v))
     write_vect(f, v)
     f.close()
-    os.system("drvmidi -i d ut.midi")  
+    os.system("timidity ut.midi")  
     os.system("rm ut.midi")
     
