@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007 Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 import sys, os, tempfile, signal
 import mfutils
 import textwrap
+from track import MidiEventStream
 
 def ms_win_kill(pid):
     import win32api
@@ -33,43 +34,38 @@ class MidiFileSynth:
         self.error_report_cb = None
         self.m_pidfile = tempfile.mkstemp()[1]
         if sys.platform == 'win32':
-            self.play_track = self._play_track_system
+            self.play_midieventstream = self._play_midieventstream_system
         else:
-            self.play_track = self._play_track_fork_execl
+            self.play_midieventstream = self._play_midieventstream_fork_execl
         if verbose_init:
             print "Solfege will use an external midiplayer program."
             print "cmdline:", self.m_cmd
             print "tmpfile:", self.m_tmpfilename
         self.__child_pid = None
     def close(self):
-	try:
+        try:
             if os.path.exists(self.m_tmpfilename):
                 os.remove(self.m_tmpfilename)
         except OSError:
             pass
-	    # We ignore this error because it seems to be easiest right now.
-	    # FIXME
+            # We ignore this error because it seems to be easiest right now.
+            # FIXME
     def join_cmd_and_filename(self, cmd, filename):
         if "%s" in cmd:
             return cmd % filename
         else:
             return " ".join((cmd, filename))
-    def _play_track_system(self, track):
-        track.prepend_bpm(60)
-        self.create_midifile(track)
+    def play_track(self, *tracks):
+        self.play_midieventstream(MidiEventStream(*tracks))
+    def _play_midieventstream_system(self, midieventstream):
+        self.create_midifile(midieventstream)
         os.system(self.join_cmd_and_filename(self.m_cmd, self.m_tmpfilename))
         # spawnl(os.P_DETACH, 'c:\\python20\\python', 'python', 'script.py')
         # #P_DETACH'ed can be killed
-    def _play_track_fork_execl(self, track):
-        track.prepend_bpm(60)
-        self.create_midifile(track)
-        err_player = None
-        if not self.m_cmd:
-            err_player = ''
-        elif not os.path.isfile(self.m_cmd.split()[0]):
-            err_player = self.m_cmd.split()[0]
-        if err_player is not None:
-            msg = _("""Failed to play music because the selected midi player program '%s' does not exist. You have to change the sound setup from the preferences window (Ctrl-F12).""") % err_player
+    def _play_midieventstream_fork_execl(self, midieventstream):
+        self.create_midifile(midieventstream)
+        if not os.path.isfile(self.m_cmd.split()[0]):
+            msg = _("""Failed to play music because the selected midi player program '%s' does not exist. You have to change the sound setup from the preferences window (Ctrl-F12).""") % self.m_cmd.split()[0]
             if self.error_report_cb:
                 self.error_report_cb(msg)
             else:
@@ -94,23 +90,24 @@ class MidiFileSynth:
                 os._exit(-1)
         else:
             self.__child_pid = pid
-    def create_midifile(self, track):
+    def create_midifile(self, stream):
         v = []
         notelen = 0
-        for e in track.m_v:
-            if e[0] == track.TEMPO:
+        v += mfutils.mf_tempo(60 * 4 / 4)
+        for e in stream:
+            if e[0] == stream.TEMPO:
                 v = v + mfutils.mf_tempo(e[1] * 4 / e[2])
-            elif e[0] == track.NOTELEN_TIME:
+            elif e[0] == stream.NOTELEN_TIME:
                 notelen = e[1]
-            elif e[0] == track.NOTE_ON:
-                v = v + mfutils.mf_note_on(int(1000 * notelen), e[1], e[2], e[3])
+            elif e[0] == stream.NOTE_ON:
+                v = v + mfutils.mf_note_on(int(96 * 4 * notelen), e[1], e[2], e[3])
                 notelen = 0
-            elif e[0] == track.NOTE_OFF:
-                v = v + mfutils.mf_note_off(int(1000 * notelen), e[1], e[2], e[3])
+            elif e[0] == stream.NOTE_OFF:
+                v = v + mfutils.mf_note_off(int(96 * 4 * notelen), e[1], e[2], e[3])
                 notelen = 0
-            elif e[0] == track.SET_PATCH:
+            elif e[0] == stream.SET_PATCH:
                 v = v + mfutils.mf_program_change(e[1], e[2])
-            elif e[0] == track.BENDER:
+            elif e[0] == stream.BENDER:
                 print "FIXME todo: seq_bender for play_with_drvmidi"
                 #m.seq_bender(DEV, e[1], e[2])
             else:
@@ -131,3 +128,27 @@ class MidiFileSynth:
                     pass
                 os.wait()
                 self.__child_pid = None
+
+def test():
+    synth = MidiFileSynth("/usr/bin/timidity %s", True)
+    sys.path.insert(0, ".")
+    import track
+    from rat import Rat
+    import src.i18n
+    src.i18n.setup(".")
+    t1 = track.Track()
+    t1.set_bpm(520, 4)
+    for i in range(70, 90):
+        t1.start_note(i, 127)
+        t1.notelen_time(Rat(1, 4))
+        t1.stop_note(i, 127)
+    t2 = track.Track()
+    for i in reversed(range(80, 100)):
+        t2.start_note(i, 127)
+        t2.notelen_time(Rat(1, 4))
+        t2.stop_note(i, 127)
+    synth.play_track(track.MidiEventStream(t1, t2))
+
+if __name__ == '__main__':
+    test()
+
