@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 
 import oss_common
 import solfege_c_midi
+from track import MidiEventStream
 
 class OSSSequencer2Synth(oss_common.AbstractSynth):
     def __init__(self, device, devnum, verbose_init):
@@ -25,7 +26,14 @@ class OSSSequencer2Synth(oss_common.AbstractSynth):
         # or can I use whatever value i want???
         solfege_c_midi.sndctl_tmr_timebase(96);
         solfege_c_midi.sndctl_tmr_tempo(60);
-    def play_track(self, track):
+    def set_patch(self):
+        """
+        Set
+        """
+        pass
+    def play_track(self, *tracks):
+        self.play_midieventstream(MidiEventStream(*tracks))
+    def play_midieventstream(self, midieventstream):
         m = solfege_c_midi
         m.sndctl_seq_reset()
         for c in range(self.NUM_CHANNELS):
@@ -33,11 +41,11 @@ class OSSSequencer2Synth(oss_common.AbstractSynth):
         m.sndctl_tmr_timebase(96);
         m.sndctl_tmr_tempo(60);
         m.seq_start_timer();
-        self.handle_midi_events(track)
-    def handle_midi_events(self, track):
+        self.handle_midi_events(midieventstream)
+    def handle_midi_events(self, midieventstream):
         m = solfege_c_midi
-        for e in track.m_v:
-            if e[0] == track.TEMPO:
+        for e in midieventstream:
+            if e[0] == midieventstream.TEMPO:
                 t = e[1] * 4 / e[2]
                 if t < 256:
                     m.sndctl_tmr_timebase(96)
@@ -47,19 +55,46 @@ class OSSSequencer2Synth(oss_common.AbstractSynth):
                         print "devmusicsynth.py: warning: bpm > 511"
                     m.sndctl_tmr_timebase(96*2)
                     m.sndctl_tmr_tempo(int(t/2))
-            elif e[0] == track.NOTE_ON:
+            elif e[0] == midieventstream.NOTE_ON:
                 m.seq_start_note(self.m_devnum, e[1], e[2], e[3])
-            elif e[0] == track.NOTE_OFF:
+            elif e[0] == midieventstream.NOTE_OFF:
                 m.seq_stop_note(self.m_devnum, e[1], e[2], e[3])
-            elif e[0] == track.NOTELEN_TIME:
+            elif e[0] == midieventstream.NOTELEN_TIME:
                 # 96 is a const, also used in soundcard.initialize that
                 # I don't understand.
                 m.seq_delta_time(int(96*4*e[1]))
-            elif e[0] == track.SET_PATCH:
+            elif e[0] == midieventstream.SET_PATCH:
                 m.seq_set_patch(self.m_devnum, e[1], e[2])
-            elif e[0] == track.BENDER:
+            elif e[0] == midieventstream.BENDER:
                 m.seq_bender(self.m_devnum, e[1], e[2])
             else:
-                raise "Corrupt track error"
+                raise "Corrupt midieventstream error"
         m.seqbuf_dump()
 
+def test():
+    synth = OSSSequencer2Synth("/dev/sequencer2", 1, None)
+    import sys, track
+    from rat import Rat
+    sys.path.insert(0, ".")
+    import src.i18n
+    src.i18n.setup(".")
+    src.i18n.setup(".")
+    t1 = track.Track()
+    t1.start_note(70, 127)
+    t1.notelen_time(Rat(1, 4))
+    t1.stop_note(70, 127)
+    t1.start_note(70, 127)
+    t1.notelen_time(Rat(1, 4))
+    t1.stop_note(70, 127)
+    t1.set_patch(8)
+    t1.start_note(71, 126)
+    t1.notelen_time(Rat(1, 16))
+    t1.stop_note(71, 126)
+    t2 = track.Track()
+    t2.start_note(80, 127)
+    t2.notelen_time(Rat(1, 2))
+    t2.stop_note(80, 127)
+    synth.play_track(track.MidiEventStream(t1, t2))
+
+if __name__ == '__main__':
+    test()
