@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -112,7 +112,7 @@ class Teacher(cfg.ConfigUtils):
 
 You really should restart the program now.""")
             return
-        if filter(lambda q: q['music'].m_musictype == 'cmdline',
+        if filter(lambda q: 'music' in q and q['music'].m_musictype == 'cmdline',
                   self.m_P.m_questions):
             run = gu.dialog_yesno(_("The lessonfile contain potentially dangerous code because it run external programs. Run anyway?"))
             if not run:
@@ -214,16 +214,128 @@ class MelodicIntervalTeacher(Teacher):
         t = self.m_tonika
         m = soundcard.Track()
         m.set_bpm(self.get_int('config/default_bpm'))
-        m.set_patch(0, self.get_int('config/preferred_instrument'))
-        m.note(4, 0, self.m_tonika.semitone_pitch(),
+        m.set_patch(self.get_int('config/preferred_instrument'))
+        m.note(4, self.m_tonika.semitone_pitch(),
                self.get_int('config/preferred_instrument_velocity'))
         for i in self.m_question:
             t = t + i
-            m.note(4, 0, t.semitone_pitch(),
+            m.note(4, t.semitone_pitch(),
                    self.get_int('config/preferred_instrument_velocity'))
         soundcard.synth.play_track(m)
 
 
+class RhythmAddOnClass:
+    RHYTHMS = ("c4", "c8 c8", "c16 c16 c16 c16", "c8 c16 c16",
+               "c16 c16 c8", "c16 c8 c16", "c8. c16", "c16 c8.",
+               "r4", "r8c8", "r8 c16 c16", "r16 c16 c8", "r16c8c16",
+               "r16 c16 c16 c16", "r8 r16 c16", "r16 c8.",
+               "c12 c12 c12", "r12 c12 c12",
+               "c12 r12 c12", "c12 c12 r12", "r12 r12 c12", "r12 c12 r12",
+               "c4.", "c4 c8", # 22, 23
+               "c8 c4", "c8 c8 c8", # 24, 25
+               "c4 c16 c16", # 26
+               "c16 c16 c4", # 27
+               "c8 c8 c16 c16", #28
+               "c8 c16 c16 c8", #29
+               "c16 c16 c8 c8", #30
+               "c8 c16 c16 c16 c16", #31
+               "c16 c16 c8 c16 c16", #32
+               "c16 c16 c16 c16 c8", #33
+               "c16 c16 c16 c16 c16 c16", #34
+               )
+    def new_question(self):
+        """returns:
+               self.ERR_PICKY : if the question is not yet solved and the
+                                   teacher is picky (== you have to solve the
+                                   question before a new is asked).
+               self.OK : if a new question was created.
+               self.ERR_NO_ELEMS : if no elements are set to be practised.
+        """
+        if self.m_timeout_handle:
+            gobject.source_remove(self.m_timeout_handle)
+            self.m_timeout_handle = None
+
+        if self.get_bool('config/picky_on_new_question') \
+                 and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
+            return self.ERR_PICKY
+
+        self.q_status = const.QSTATUS_NO
+
+        norest_v = []
+        v = []
+        for x in self.m_P.header.rhythm_elements:
+            if not (self.RHYTHMS[x][0] == "r"
+                    and self.get_bool("not_start_with_rest")):
+                norest_v.append(x)
+            v.append(x)
+        if not v:
+            return self.ERR_NO_ELEMS
+        if not norest_v:
+            return self.ERR_NO_ELEMS
+        self.m_question = [random.choice(norest_v)]
+        for x in range(1, self.get_int("num_beats")):
+            self.m_question.append(random.choice(v))
+        self.q_status = const.QSTATUS_NEW
+        return self.OK
+    def get_music_notenames(self, count_in):
+        """
+        Return a string with the notenames of the current question.
+        Include count in if count_in == True
+        """
+        s = ""
+        if count_in:
+            if self.m_P.header.count_in_notelen:
+                count_in_notelen = self.m_P.header.count_in_notelen
+            else:
+                count_in_notelen = "4"
+            for x in range(self.get_int("count_in")):
+                s = s + "d%s " % count_in_notelen
+        for k in self.m_question:
+            s = s + self.RHYTHMS[k] + " "
+        return s
+    def get_music_string(self):
+        """
+        Return a complete mpd string of the current question that can
+        be feed to mpd.play_music.
+        """
+        return r"\staff{%s}" % self.get_music_notenames(True)
+    def play_rhythm(self, rhythm):
+        """
+        rhythm is a string. Example: 'c4 c8 c8 c4'
+        """
+        score = mpd.parser.parse_to_score_object(rhythm)
+        track = score.get_midi_events_as_percussion(cfg.get_int('config/preferred_instrument_velocity'))[0]
+        track.prepend_bpm(self.m_P.header.bpm)
+        track.replace_note(mpd.notename_to_int("c"),
+                           self.get_int("config/rhythm_perc"))
+        track.replace_note(mpd.notename_to_int("d"),
+                           self.get_int("config/countin_perc"))
+        soundcard.synth.play_track(track)
+    def set_elements_variables(self):
+        """
+        This is called from the on_start_practise() method of exercise
+        modules that generate rhythms and use these variables to select
+        rhythm elements.
+        """
+        if self.m_custom_mode:
+            if not self.m_P.header.rhythm_elements:
+                self.m_P.header.rhythm_elements = self.m_P.header.configurable_rhythm_elements[:3]
+            self.m_P.header.visible_rhythm_elements = self.m_P.header.rhythm_elements[:]
+        else:
+            if not self.m_P.header.visible_rhythm_elements:
+                self.m_P.header.visible_rhythm_elements = \
+                    self.m_P.header.rhythm_elements[:]
+                self.m_P.header.rhythm_elements = \
+                  [n for n in self.m_P.header.rhythm_elements if n != 'newline']
+    def set_default_header_values(self):
+        for n, default in (('bpm', 60),
+                  ('count_in', 2),
+                  ('num_beats', 4)):
+            if n in self.m_P.header:
+                self.set_int(n, self.m_P.header[n])
+            else:
+                self.set_int(n, default)
+
 class Gui(gtk.VBox, cfg.ConfigUtils):
     """Important members:
          - practise_box
@@ -409,6 +521,75 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
             return True
         return False
 
+class RhythmAddOnGuiClass(object):
+    def add_select_elements_gui(self):
+        self.g_element_frame = frame = gtk.Frame(_("Rhythms to use in question"))
+        self.config_box.pack_start(frame, False)
+        self.g_select_rhythms_box = gu.NewLineBox()
+        self.g_select_rhythms_box.set_border_width(gu.PAD_SMALL)
+        frame.add(self.g_select_rhythms_box)
+    def add_select_num_beats_gui(self):
+        table = gtk.Table(2, 4, False)
+        self.config_box.pack_start(table, False)
+        ###
+        label = gtk.Label(_("Number of beats in question:"))
+        label.set_alignment(1.0, 0.5)
+        table.attach(label, 0, 1, 0, 1, xpadding=gu.PAD_SMALL,
+                      xoptions=gtk.FILL)
+        table.attach(gu.nSpinButton(self.m_exname, "num_beats",
+                     gtk.Adjustment(4, 1, 100, 1, 10)),
+                     1, 2, 0, 1, xoptions=gtk.FILL)
+        label = gtk.Label(_("Count in before question:"))
+        label.set_alignment(1.0, 0.5)
+        table.attach(label, 0, 1, 1, 2, xpadding=gu.PAD_SMALL,
+                     xoptions=gtk.FILL)
+        table.attach(gu.nSpinButton(self.m_exname, "count_in",
+                     gtk.Adjustment(2, 0, 10, 1, 10)),
+                     1, 2, 1, 2, xoptions=gtk.FILL)
+        table.show_all()
+    def pngcheckbutton(self, i):
+        btn = gtk.CheckButton()
+        btn.add(gu.create_rhythm_image(RhythmAddOnClass.RHYTHMS[i]))
+        btn.show()
+        btn.connect('clicked', self.select_element_cb, i)
+        return btn
+    def update_select_elements_buttons(self):
+        """
+        (Re)create the checkbuttons used to select which rhythm elements
+        to be used when creating questions. We only need to do this if
+        we are in m_custom_mode.
+        """
+        self.g_select_rhythms_box.empty()
+        for n in self.m_t.m_P.header.configurable_rhythm_elements:
+            if n == 'newline':
+                self.g_select_rhythms_box.newline()
+            else:
+                b = self.pngcheckbutton(n)
+                self.g_select_rhythms_box.add_widget(b)
+                b.set_active(n in self.m_t.m_P.header.rhythm_elements)
+        self.g_select_rhythms_box.show_widgets()
+    def select_element_cb(self, button, element_num):
+        def sortlike(orig, b):
+            ret = []
+            for n in orig:
+                if n == 'newline':
+                    ret.append('newline')
+                elif n in b:
+                    ret.append(n)
+            return ret
+        if button.get_active():
+            if element_num not in self.m_t.m_P.header.rhythm_elements:
+                self.m_t.m_P.header.rhythm_elements.append(element_num)
+                self.m_t.m_P.header.rhythm_elements = sortlike(
+                    self.m_t.m_P.header.configurable_rhythm_elements,
+                    self.m_t.m_P.header.rhythm_elements)
+        else:
+            if element_num in self.m_t.m_P.header.rhythm_elements:
+                self.m_t.m_P.header.rhythm_elements.remove(element_num)
+        self.m_t.m_P.header.visible_rhythm_elements = \
+            self.m_t.m_P.header.rhythm_elements[:]
+        self.m_t.m_P.header.rhythm_elements = \
+            [n for n in self.m_t.m_P.header.rhythm_elements if n != 'newline']
 
 class IntervalGui(Gui):
     """
