@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ def check_rcfile():
     """See default.config for rcfileversion values, meanings and
     a description of how to add config variables.
     """
-    rcfileversion = 11
+    rcfileversion = 12
     if cfg.get_int("app/rcfileversion") > rcfileversion:
         cfg.drop_user_config()
         return
@@ -87,6 +87,10 @@ def check_rcfile():
         for n in cfg.iterate_sections():
             cfg.del_key("%s/lessoncollection" % n)
             cfg.del_key("%s/lessonfile" % n)
+    if cfg.get_int("app/rcfileversion") <= 11:
+        for s in ('rhythm', 'rhythmtapping2'):
+            cfg.del_key("%s/countin_perc" % s)
+            cfg.del_key("%s/rhythm_perc" % s)
     cfg.set_int("app/rcfileversion", rcfileversion)
 
 class SolfegeApp(cfg.ConfigUtils):
