@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -65,36 +65,27 @@ class Teacher(abstract.Teacher):
         if self.q_status == const.QSTATUS_NO:
             return
         low_instr, low_vel, high_instr, high_vel = self.get_instrument_config(2)
-        m = soundcard.Track()
-        m.set_patch(0, low_instr)
-        m.set_patch(1, high_instr)
+        t1 = soundcard.Track()
+        t2 = soundcard.Track()
+        t1.set_patch(low_instr)
+        t2.set_patch(high_instr)
         if self.get_string('first_interval_type') == 'harmonic':
-            m.start_note(0, self.m_tonikas[0], low_vel)
-            m.start_note(1, self.m_tonikas[0] + self.m_intervals[0], high_vel)
-            m.notelen_time(4)
-            m.stop_note(0, self.m_tonikas[0], low_vel)
-            m.stop_note(1, self.m_tonikas[0] + self.m_intervals[0], high_vel)
+            t1.note(4, self.m_tonikas[0], low_vel)
+            t2.note(4, self.m_tonikas[0] + self.m_intervals[0], high_vel)
         else:
-            m.start_note(0, self.m_tonikas[0], low_vel)
-            m.notelen_time(4)
-            m.stop_note(0, self.m_tonikas[0], low_vel)
-            m.start_note(1, self.m_tonikas[0] + self.m_intervals[0], high_vel)
-            m.notelen_time(4)
-            m.stop_note(1, self.m_tonikas[0] + self.m_intervals[0], high_vel)
+            t1.note(4, self.m_tonikas[0], low_vel)
+            t1.notelen_time(4)
+            t2.notelen_time(4)
+            t2.note(4, self.m_tonikas[0] + self.m_intervals[0], high_vel)
         if self.get_string('last_interval_type') == 'harmonic':
-            m.start_note(0, self.m_tonikas[1], low_vel)
-            m.start_note(1, self.m_tonikas[1] + self.m_intervals[1], high_vel)
-            m.notelen_time(4)
-            m.stop_note(0, self.m_tonikas[1], low_vel)
-            m.stop_note(1, self.m_tonikas[1] + self.m_intervals[1], high_vel)
+            t1.note(4, self.m_tonikas[1], low_vel)
+            t2.note(4, self.m_tonikas[1] + self.m_intervals[1], high_vel)
         else:
-            m.start_note(0, self.m_tonikas[1], low_vel)
-            m.notelen_time(4)
-            m.stop_note(0, self.m_tonikas[1], low_vel)
-            m.start_note(1, self.m_tonikas[1] + self.m_intervals[1], high_vel)
-            m.notelen_time(4)
-            m.stop_note(1, self.m_tonikas[1] + self.m_intervals[1], high_vel)
-        soundcard.synth.play_track(m)
+            t1.note(4, self.m_tonikas[1], low_vel)
+            t1.notelen_time(4)
+            t2.notelen_time(4)
+            t2.note(4, self.m_tonikas[1] + self.m_intervals[1], high_vel)
+        soundcard.synth.play_track(t1, t2)
     def guess_answer(self, c):
         """
         argument c:
