@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -92,6 +92,17 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
               = InstrumentConfigurator("config", 3,
                     _("Use different instruments for chords and harmonic intervals."))
         category_vbox.pack_start(self.g_instrument_configurator, False)
+
+        vbox, category_box = gu.hig_category_vbox(_("Preferred percussion instruments"))
+        page_vbox.pack_start(vbox, False)
+        category_box.pack_start(gu.hig_label_widget(
+            _("Count in:"),
+            gu.PercussionNameComboBoxEntry("config", "countin_perc", "Claves"),
+            sizegroup))
+        category_box.pack_start(gu.hig_label_widget(
+            _("Rhythm:"),
+            gu.PercussionNameComboBoxEntry("config", "rhythm_perc", "Side Stick"),
+            sizegroup))
         ########
         # user #
         ########
