@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -141,7 +141,7 @@ class Gui(abstract.LessonbasedGui):
                        self.get_int('config/preferred_instrument_velocity'),
                        start, end)
                 track.prepend_bpm(*self.m_t.m_P.get_tempo())
-                track.prepend_patch(0, self.get_int('config/preferred_instrument'))
+                track.prepend_patch(self.get_int('config/preferred_instrument'))
                 soundcard.synth.play_track(track)
             except Exception, e:
                 if not self.standard_exception_handler(e, __file__,
