@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@ import gobject
 import re
 import soundcard
 import cfg
+import os
 
 PAD = 8
 PAD_SMALL = 4
@@ -359,9 +360,9 @@ class HarmonicProgressionLabel(gtk.HBox):
             self.pack_start(gtk.HBox())
         self.show_all()
     def get_next_token(self):
-        m_re1 = re.compile("([^\(]+)", re.UNICODE)
-        m_re2 = re.compile("\((\w*),\s*(\w*)\)", re.UNICODE)
-        m_re3 = re.compile("\((\w*)\)", re.UNICODE)
+        m_re1 = re.compile("([^\(]+)")
+        m_re2 = re.compile("\((\w*),\s*(\w*)\)")
+        m_re3 = re.compile("\((\w*)\)")
         m1 = m_re1.match(self.m_str)
         m2 = m_re2.match(self.m_str)
         m3 = m_re3.match(self.m_str)
@@ -459,4 +460,22 @@ class NewLineBox(gtk.VBox):
     def get_max_child_height(self):
         return max([c.size_request()[1] for c in self.m_todo_widgets])
 
+def create_png_image(fn):
+    """
+    Create an image by loading a png file from graphics dir
+    """
+    im = gtk.Image()
+    im.set_from_file(os.path.join('graphics', fn)+'.png')
+    im.show()
+    return im
+
+def create_rhythm_image(rhythm):
+    """
+    rhythm : a string like 'c8 c8' or 'c8 c16 c16'
+    The image returned is shown.
+    """
+    im = gtk.Image()
+    im.set_from_file(os.path.join('graphics', 'rhythm-%s.png' % (rhythm.replace(" ", ""))))
+    im.show()
+    return im
 
