@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -123,16 +123,20 @@ class Teacher(abstract.Teacher):
         low_tone = self.m_tonika.semitone_pitch()
         high_tone = (self.m_tonika+self.m_interval).semitone_pitch()
 
-        m = soundcard.Track()
-        m.set_bpm(self.get_int('config/default_bpm'))
-        m.set_patch(0, instr_low)
-        m.set_patch(1, instr_high)
-        m.start_note(0, low_tone, instr_low_vel)
-        m.start_note(1, high_tone, instr_high_vel)
-        m.notelen_time(4)
-        m.stop_note(0, low_tone, instr_low_vel)
-        m.stop_note(1, high_tone, instr_high_vel)
-        soundcard.synth.play_track(m)
+        t1 = soundcard.Track()
+        t1.set_bpm(self.get_int('config/default_bpm'))
+        t1.set_patch(instr_low)
+        t1.start_note(low_tone, instr_low_vel)
+        t1.notelen_time(4)
+        t1.stop_note(low_tone, instr_low_vel)
+
+        t2 = soundcard.Track()
+        t1.set_bpm(self.get_int('config/default_bpm'))
+        t1.set_patch(instr_high)
+        t2.start_note(high_tone, instr_high_vel)
+        t2.notelen_time(4)
+        t2.stop_note(high_tone, instr_high_vel)
+        soundcard.synth.play_track(t1, t2)
         return 1
     def play_melodic(self):
         if self.q_status == const.QSTATUS_NO:
@@ -150,10 +154,10 @@ class Teacher(abstract.Teacher):
         high_tone = (self.m_tonika+self.m_interval).semitone_pitch()
         m = soundcard.Track()
         m.set_bpm(self.get_int('config/default_bpm'))
-        m.set_patch(0, instr_low)
-        m.set_patch(1, instr_high)
-        m.note(4, 0, low_tone, instr_low_vel)
-        m.note(4, 1, high_tone, instr_high_vel)
+        m.set_patch(instr_low)
+        m.note(4, low_tone, instr_low_vel)
+        m.set_patch(instr_high)
+        m.note(4, high_tone, instr_high_vel)
         soundcard.synth.play_track(m)
 
 class Gui(abstract.IntervalGui):
@@ -253,20 +257,23 @@ class Gui(abstract.IntervalGui):
             # we only get here if you use one if the instrument widgets, not
             # with the buttons interface.
             soundcard.play_note(self.get_int('config/preferred_instrument'),
-                          4, 0, midi_int,
+                          4, midi_int,
                           self.get_int('config/preferred_instrument_velocity'))
         elif mouse_button == 3 and self.m_t.q_status != const.QSTATUS_NO:
             instr_low, instr_low_vel, instr_high, instr_high_vel = self.m_t.get_instrument_config(2)
             n2 = self.m_t.m_tonika + interval
-            m = soundcard.Track()
-            m.set_patch(0, instr_low)
-            m.set_patch(1, instr_high)
-            m.start_note(0, self.m_t.m_tonika.semitone_pitch(), instr_low_vel)
-            m.start_note(1, n2.semitone_pitch(), instr_low_vel)
-            m.notelen_time(4)
-            m.stop_note(0, self.m_t.m_tonika.semitone_pitch(), instr_high_vel)
-            m.stop_note(1, n2.semitone_pitch(), instr_high_vel)
-            soundcard.synth.play_track(m)
+            t1 = self.m_t.m_tonika + interval
+            t1 = soundcard.Track()
+            t1.set_patch(instr_low)
+            t1.start_note(self.m_t.m_tonika.semitone_pitch(), instr_low_vel)
+            t1.notelen_time(4)
+            t1.stop_note(self.m_t.m_tonika.semitone_pitch(), instr_high_vel)
+            t2 = soundcard.Track()
+            t2.set_patch(instr_high)
+            t2.start_note(n2.semitone_pitch(), instr_low_vel)
+            t2.notelen_time(4)
+            t2.stop_note(n2.semitone_pitch(), instr_high_vel)
+            soundcard.synth.play_track(t1, t2)
     def new_question(self, _o=None):
         """This function is called when you click on the 'New interval'
         button, or when you use the key bindings. So it can be called even
