@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ class Teacher(abstract.Teacher):
             gobject.source_remove(self.m_timeout_tag)
             self.m_timeout_tag = None
     def tick(self, _o=None):
-        soundcard.play_note(0, 8, 9, 60, 90)
+        soundcard.play_perc(8, 60, 90)
         return 1
     def guess_answer(self, bpm):
         assert self.q_status != const.QSTATUS_NO
