@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -86,7 +86,7 @@ class Teacher(abstract.Teacher):
     def play_question(self):
         if self.q_status == const.QSTATUS_NO:
             return
-        soundcard.play_note(self.get_int('config/preferred_instrument'), 4, 0, 
+        soundcard.play_note(self.get_int('config/preferred_instrument'), 4,
              mpd.notename_to_int(self.m_question)+self.m_octave*12,
              self.get_int('config/preferred_instrument_velocity'))
     def give_up(self):
@@ -94,13 +94,16 @@ class Teacher(abstract.Teacher):
             self.m_statistics.reset_session()
         self.q_status = const.QSTATUS_GIVE_UP
     def spank_me_play_question(self):
-        track = soundcard.Track()
-        track.note(8, 9, 71, self.get_int('config/preferred_instrument_velocity'))
-        track.set_patch(0, self.get_int('config/preferred_instrument'))
-        track.note(4, 0, mpd.notename_to_int(self.m_question)+self.m_octave*12, self.get_int('config/preferred_instrument_velocity'))
-        soundcard.synth.play_track(track)
+        t1 = soundcard.PercussionTrack()
+        t1.note(8, 71, self.get_int('config/preferred_instrument_velocity'))
+        t2 = soundcard.Track()
+        t2.notelen_time(4)
+        t2.set_patch(self.get_int('config/preferred_instrument'))
+        t2.note(4, mpd.notename_to_int(self.m_question)+self.m_octave*12,
+                self.get_int('config/preferred_instrument_velocity'))
+        soundcard.synth.play_track(t1, t2)
     def spank_me(self):
-        soundcard.play_note(0, 4, 9, 71, self.get_int('config/preferred_instrument_velocity'))
+        soundcard.play_perc(4, 71, self.get_int('config/preferred_instrument_velocity'))
 
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
