@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -201,7 +201,7 @@ class PianoOctaveWithAccelName(PianoKeyboard):
     def on_button_press_event(self, event, midi_int):
         if event.button == 3:
             soundcard.play_note(cfg.get_int('config/preferred_instrument'),
-                           4, 0, midi_int,
+                           4, midi_int,
                            cfg.get_int('config/preferred_instrument_velocity'))
         elif event.button == 1:
             self.m_callback(mpd.int_to_notename(midi_int))
