@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ import soundcard
 import dataparser
 import osutils
 
-class plstring(unicode):
+class plstring(str):
     pass
 
 # The keys in the dict say how many steps up or down in the
@@ -112,6 +112,8 @@ keywords = (
     'identifybpm',
     'nameinterval',
     'elembuilder',
+    'rhythmtapping',
+    'rhythmtapping2',
     #
     'harmonic',
     'melodic',
@@ -120,6 +122,7 @@ keywords = (
     'voice',
     'rvoice',
     'satb',
+    'rhythm',
     'cmdline',
     'wavfile',
     'midifile',
@@ -164,6 +167,8 @@ lessonfile_functions = {
         'satb': lambda m: Music(m, 'satb'),
         'voice': lambda m: Music(m, 'voice'),
         'rvoice': lambda m: Music(m, 'rvoice'),
+        'rhythm': lambda m: Music(m, 'rhythm'),
+        'percussion': lambda m: Music(m, 'percussion'),
         'cmdline': lambda m: Music(m, 'cmdline'),
         'wavfile': lambda m: Music(m, 'wavfile'),
         'midifile': lambda m: Music(m, 'midifile'),
@@ -242,7 +247,7 @@ class LessonfileCommon(object):
         for question in self.m_questions:
             question['active'] = 1
             # FIXMECOMPAT
-            if isinstance(question['music'], basestring):
+            if 'music' in question and isinstance(question['music'], basestring):
                 # The following line is for backward compatibility
                 question['music'] = Music(question['music'], self.header.musicformat)
             question['m_lessonfile'] = self
@@ -422,6 +427,8 @@ class QuestionsLessonfile(LessonfileCommon):
             return self.prepare_music_string_normal_format(question, varname)
         elif question[varname].m_musictype == 'satb':
             return self.prepare_music_string_satb_format(question, varname)
+        elif question[varname].m_musictype in ('rhythm', 'percussion'):
+            return r"\staff{ %s }" % question[varname].m_musicdata
         elif question[varname].m_musictype == 'voice':
             return r"\staff\transpose %s{ %s }" \
               % (self.m_transpose.get_octave_notename(), question[varname].m_musicdata)
@@ -572,12 +579,33 @@ class QuestionsLessonfile(LessonfileCommon):
             soundcard.play_midi_file(os.path.join(
                 os.path.split(self.m_t.m_lessonfile)[0],
                 question[varname].m_musicdata))
+        elif question[varname].m_musictype in 'rhythm':
+            self.play_question_musicformat_rhythm(question, varname)
+        elif question[varname].m_musictype in 'percussion':
+            self.play_question_musicformat_percussion(question, varname)
         elif question[varname].m_musictype in ('normal', 'satb', 'voice', 'rvoice'):
             self.play_question_musicformat_normal_satb(question, varname)
         elif question[varname].m_musictype in 'chord':
             self.play_question_musicformat_chord(question, varname)
         else:
             raise LessonfileException("Unrecognised musictype '%s'" % question[varname].m_musictype)
+    def play_question_musicformat_rhythm(self, question, varname):
+        """
+        This will play music objects of the type 'rhythm'. See the
+        docbook documentation for a description.
+        """
+        #FIXME can this be used by src.rhythm too?
+        score = mpd.parser.parse_to_score_object(question.get_music(varname))
+        track = score.get_midi_events_as_percussion(cfg.get_int('config/preferred_instrument_velocity'))[0]
+        track.prepend_bpm(self.get_tempo()[0], self.get_tempo()[1])
+        track.replace_note(mpd.notename_to_int("c"), 37)
+        track.replace_note(mpd.notename_to_int("d"), 80)
+        soundcard.synth.play_track(track)
+    def play_question_musicformat_percussion(self, question, varname):
+        score = mpd.parser.parse_to_score_object(question.get_music(varname))
+        track = score.get_midi_events_as_percussion(cfg.get_int('config/preferred_instrument_velocity'))[0]
+        track.prepend_bpm(self.get_tempo()[0], self.get_tempo()[1])
+        soundcard.synth.play_track(track)
     def play_question_musicformat_normal_satb(self, question, varname):
         instrument = self.prepare_instrument_list(question)
         mpd.play_music(question.get_music(varname), self.get_tempo(),
@@ -603,29 +631,23 @@ class QuestionsLessonfile(LessonfileCommon):
                        instrument[0], instrument[1])
         else:
             assert len(instrument) == 6
-            track = soundcard.Track()
-            track.set_bpm(cfg.get_int('config/default_bpm'))#FIXME skulle dette vart tatt fra lesson file?
+            t1 = soundcard.Track()
+            t2 = soundcard.Track()
+            t3 = soundcard.Track()
+            t1.set_bpm(cfg.get_int('config/default_bpm'))#FIXME skulle dette vart tatt fra lesson file?
             nlist = self.music_to_notename_list(question[varname])
-            # set patches
-            track.set_patch(0, instrument[0])
-            for x in range(1, len(nlist)-1):
-                track.set_patch(x, instrument[2])
-            track.set_patch(len(nlist)-1, instrument[4])
+            t1.set_patch(instrument[0])
+            t2.set_patch(instrument[2])
+            t3.set_patch(instrument[4])
             # start notes
-            track.start_note(0, mpd.notename_to_int(nlist[0]), instrument[1])
-            for x, notename in enumerate(nlist[1:-1]):
-                track.start_note(x+1, mpd.notename_to_int(notename),
-                        instrument[3])
-            track.start_note(len(nlist)-1, mpd.notename_to_int(nlist[-1]), instrument[5])
-            # delay
-            track.notelen_time(4)
-            # stop notes
-            track.stop_note(0, mpd.notename_to_int(nlist[0]), instrument[1])
-            for x, notename in enumerate(nlist[1:-1]):
-                track.stop_note(x+1, mpd.notename_to_int(notename),
-                                   instrument[3])
-            track.stop_note(len(nlist)-1, mpd.notename_to_int(nlist[-1]), instrument[5])
-            soundcard.synth.play_track(track)
+            t1.note(4, mpd.notename_to_int(nlist[0]), instrument[1])
+            for notename in nlist[1:-1]:
+                t2.start_note(mpd.notename_to_int(notename), instrument[3])
+            t2.notelen_time(4)
+            for notename in nlist[1:-1]:
+                t2.stop_note(mpd.notename_to_int(notename), instrument[3])
+            t3.note(4, mpd.notename_to_int(nlist[-1]), instrument[5])
+            soundcard.synth.play_track(t1, t2, t3)
     def play_question_arpeggio(self, varname='music'):
         musictype = self.get_question()[varname].m_musictype
         if musictype == 'chord':
@@ -646,44 +668,47 @@ class QuestionsLessonfile(LessonfileCommon):
                        instrument[0], instrument[1])
         else:
             assert len(instrument) == 6
-            track = soundcard.Track()
-            track.set_bpm(cfg.get_int('config/arpeggio_bpm'))
+            t1 = soundcard.Track()
+            t2 = soundcard.Track()
+            t3 = soundcard.Track()
+            t1.set_bpm(cfg.get_int('config/arpeggio_bpm'))
             nlist = self.get_music_as_notename_list(varname)
             # set patches
-            track.set_patch(0, instrument[0])
-            for x in range(1, len(nlist)-1):
-                track.set_patch(x, instrument[2])
-            track.set_patch(len(nlist)-1, instrument[4])
+            t1.set_patch(instrument[0])
+            t2.set_patch(instrument[2])
+            t3.set_patch(instrument[4])
             # start notes
-            track.note(4, 0, mpd.notename_to_int(nlist[0]), instrument[1])
-            for x, notename in enumerate(nlist[1:-1]):
-                track.note(4, x+1, mpd.notename_to_int(notename),
-                                    instrument[3])
-            track.note(4, len(nlist)-1, mpd.notename_to_int(nlist[-1]), instrument[5])
-            soundcard.synth.play_track(track)
+            t1.note(4, mpd.notename_to_int(nlist[0]), instrument[1])
+            t2.notelen_time(4)
+            t3.notelen_time(4)
+            for notename in nlist[1:-1]:
+                t2.note(4, mpd.notename_to_int(notename), instrument[3])
+                t3.notelen_time(4)
+            t3.note(4, mpd.notename_to_int(nlist[-1]), instrument[5])
+            soundcard.synth.play_track(t1, t2, t3)
     def play_question_musicformat_satb_arpeggio(self, varname='music'):
         """FIXME -- for completeness, should this function should take a question argument?
         """
         instrument = self.prepare_instrument_list(self.get_question())
         track = soundcard.Track()
         track.set_bpm(cfg.get_int('config/default_bpm'))
-        track.set_patch(0, instrument[0])
-        for x in [0, 1]:
+        track.set_patch(instrument[0])
+        for x in 0, 1:
             v = self.get_music_as_notename_list(varname)[x]
             s = v.strip().split(" ")
             for n in s:
                 if cfg.get_string('user/sex') == 'female':
-                    track.note(4, 0, mpd.notename_to_int(n), instrument[1])
+                    track.note(4, mpd.notename_to_int(n), instrument[1])
                 else:
-                    track.note(4, 0, mpd.notename_to_int(n)-12, instrument[1])
-        for x in [2, 3]:
+                    track.note(4, mpd.notename_to_int(n)-12, instrument[1])
+        for x in 2, 3:
             v = self.get_music_as_notename_list(varname)[x]
             s = v.strip().split(" ")
             for n in s:
                 if cfg.get_string('user/sex') == 'male':
-                    track.note(4, 0, mpd.notename_to_int(n), instrument[1])
+                    track.note(4, mpd.notename_to_int(n), instrument[1])
                 else:
-                    track.note(4, 0, mpd.notename_to_int(n)+12, instrument[1])
+                    track.note(4, mpd.notename_to_int(n)+12, instrument[1])
         soundcard.synth.play_track(track)
     def play_question_as_choral(self, question, varname='music'):
         instrument = self.prepare_instrument_list(self.get_question())
@@ -692,17 +717,14 @@ class QuestionsLessonfile(LessonfileCommon):
         # FIXME, only the velocity from instrument[1] is used since
         # music_to_tracklist is not complete.
         tracklist = mpd.music_to_tracklist(question.get_music(varname), instrument[1])
-        tracklist[0].prepend_patch(0, instrument[4])
-        track = tracklist[0]
+        tracklist[0].prepend_patch(instrument[4])
         a, b = self.get_tempo()
         # FIXME the bpm api is wrong. We set the tempo to one track, and it works for all.
-        track.prepend_bpm(a, b)
-        for x in range(1, len(tracklist)-1):
-            tracklist[x].prepend_patch(x, instrument[2])
-            track.merge_with(tracklist[x])
-        tracklist[-1].prepend_patch(len(tracklist)-1, instrument[0])
-        track.merge_with(tracklist[-1])
-        soundcard.synth.play_track(track)
+        tracklist[0].prepend_bpm(a, b)
+        for track in tracklist[:-1][:1]:
+            track.prepend_patch(instrument[2])
+        tracklist[-1].prepend_patch(instrument[0])
+        soundcard.synth.play_track(*tracklist)
     def prepare_instrument_list(self, question):
         """Return a list created from the instrument variable the question.
         Use app default values if the variable is missing.
