@@ -1,7 +1,7 @@
 # -*- coding: iso-8859-1 -*-
 
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -185,6 +185,8 @@ import identifybpm
 import harmonicprogressiondictation
 import singanswer
 import elembuilder
+import rhythmtapping
+import rhythmtapping2
 
 import learning_tree_editor
 from docviewer import DocViewer
@@ -326,12 +328,11 @@ class MainWin(App, cfg.ConfigUtils):
           ('AppQuit', 'gtk-quit', None, None, None, self.quit_program),
         ])
         self.m_action_groups['NotExit'].add_actions([
-          ('MiscMenu', None, _('_Misc exercises')),
-          ('TheoryMenu', None, _('_Theory')),
+          ('TheoryMenu', None, _('The_ory')),
           ('TheoryIntervals', None, _('_Intervals'), None, None,
             lambda o: self.m_app.handle_href('theory-intervals.html')),
           ('EditMenu', None, _("_Edit")),
-          ('TreeEditor', None, _('Learning tree'), None, None,
+          ('TreeEditor', None, _('Edit learning tree'), None, None,
             self.do_tree_editor),
           ('TestsMenu', None, _("_Tests")),
           ('OpenPreferencesWindow', 'gtk-preferences', None, '<ctrl>F12', None,
