@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -133,10 +133,10 @@ class Gui(abstract.IntervalGui):
             n = self.m_t.m_tonika + i
             track = soundcard.Track()
             track.set_bpm(self.get_int('config/default_bpm'))
-            track.set_patch(0, self.get_int('config/preferred_instrument'))
-            track.note(4, 0, self.m_t.m_tonika.semitone_pitch(),
+            track.set_patch(self.get_int('config/preferred_instrument'))
+            track.note(4, self.m_t.m_tonika.semitone_pitch(),
                     self.get_int('config/preferred_instrument_velocity'))
-            track.note(4, 0, n.semitone_pitch(),
+            track.note(4, n.semitone_pitch(),
                     self.get_int('config/preferred_instrument_velocity'))
             soundcard.synth.play_track(track)
             return
@@ -154,7 +154,7 @@ class Gui(abstract.IntervalGui):
             # midi_int is only set when we use some of the instrument widgets,
             # not when we use the buttons interface.
             soundcard.play_note(self.get_int('config/preferred_instrument'),
-                        4, 0, midi_int,
+                        4, midi_int,
                         self.get_int('config/preferred_instrument_velocity'))
         if self.m_t.q_status == const.QSTATUS_GIVE_UP:
             return
