@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,98 +18,22 @@
 from __future__ import division
 import gtk, gobject
 import abstract, const, gu, mpd, soundcard
-import random, os
+import random
 import cfg
 import lessonfile
 
-RHYTHMS = ("c4", "c8 c8", "c16 c16 c16 c16", "c8 c16 c16",
-           "c16 c16 c8", "c16 c8 c16", "c8. c16", "c16 c8.",
-           "r4", "r8c8", "r8 c16 c16", "r16 c16 c8", "r16c8c16",
-           "r16 c16 c16 c16", "r8 r16 c16", "r16 c8.",
-           "c12 c12 c12", "r12 c12 c12",
-           "c12 r12 c12", "c12 c12 r12", "r12 r12 c12", "r12 c12 r12",
-           "c4.", "c4 c8", # 22, 23
-           "c8 c4", "c8 c8 c8", # 24, 25
-           "c4 c16 c16", # 26
-           "c16 c16 c4", # 27
-           "c8 c8 c16 c16", #28
-           "c8 c16 c16 c8", #29
-           "c16 c16 c8 c8", #30
-           "c8 c16 c16 c16 c16", #31
-           "c16 c16 c8 c16 c16", #32
-           "c16 c16 c16 c16 c8", #33
-           "c16 c16 c16 c16 c16 c16", #34
-           )
 
-
-class Teacher(abstract.Teacher):
+class Teacher(abstract.Teacher, abstract.RhythmAddOnClass):
     OK = 0
     ERR_PICKY = 1
     ERR_NO_ELEMS = 2
     def __init__(self, exname, app):
         abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.HeaderLessonfile
-    def new_question(self):
-        """returns:
-               Teacher.ERR_PICKY : if the question is not yet solved and the
-                                   teacher is picky (== you have to solve the
-                                   question before a new is asked).
-               Teacher.OK : if a new question was created.
-               Teacher.ERR_NO_ELEMS : if no elements are set to be practised.
-        """
-        if self.m_timeout_handle:
-            gobject.source_remove(self.m_timeout_handle)
-            self.m_timeout_handle = None
-
-        if self.get_bool('config/picky_on_new_question') \
-                 and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
-            return Teacher.ERR_PICKY
-
-        self.q_status = const.QSTATUS_NO
-
-        norest_v = []
-        v = []
-        for x in self.m_P.header.rhythm_elements:
-            if not (RHYTHMS[x][0] == "r"
-                    and self.get_bool("not_start_with_rest")):
-                norest_v.append(x)
-            v.append(x)
-        if not v:
-            return Teacher.ERR_NO_ELEMS
-        if not norest_v:
-            return Teacher.ERR_NO_ELEMS
-        self.m_question = [random.choice(norest_v)]
-        for x in range(1, self.get_int("num_beats")):
-            self.m_question.append(random.choice(v))
-        self.q_status = const.QSTATUS_NEW
-        return Teacher.OK
-    def get_music_string(self):
-        if self.m_P.header.count_in_notelen:
-            count_in_notelen = self.m_P.header.count_in_notelen
-        else:
-            count_in_notelen = "4"
-        s = ""
-        for x in range(self.get_int("count_in")):
-            s = s + "d%s " % count_in_notelen
-        for k in self.m_question:
-            s = s + RHYTHMS[k] + " "
-        return r"\staff{%s}" % s
     def play_question(self):
         if self.q_status == const.QSTATUS_NO:
             return
         self.play_rhythm(self.get_music_string())
-    def play_rhythm(self, rhythm):
-        """
-        rhythm is a string. Example: 'c4 c8 c8 c4'
-        """
-        score = mpd.parser.parse_to_score_object(rhythm)
-        track = score.get_midi_events_with_channel(9, cfg.get_int('config/preferred_instrument_velocity'))[0]
-        track.prepend_bpm(self.get_int("bpm"))
-        track.replace_note(mpd.notename_to_int("c"),
-                           self.get_int("rhythm_perc"), 9)
-        track.replace_note(mpd.notename_to_int("d"),
-                           self.get_int("countin_perc"), 9)
-        soundcard.synth.play_track(track)
     def guess_answer(self, a):
         assert self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]
         v = []
@@ -124,24 +48,6 @@ class Teacher(abstract.Teacher):
             self.q_status = const.QSTATUS_WRONG
             self.m_app.play_sad_sound()
 
-def create_png_image(fn):
-    """
-    Create an image by loading a png file from graphics dir
-    """
-    im = gtk.Image()
-    im.set_from_file(os.path.join('graphics', fn)+'.png')
-    im.show()
-    return im
-
-def create_rhythm_image(rhythm):
-    """
-    rhythm : a string like 'c8 c8' or 'c8 c16 c16'
-    The image returned is shown.
-    """
-    im = gtk.Image()
-    im.set_from_file(os.path.join('graphics', 'rhythm-%s.png' % (rhythm.replace(" ", ""))))
-    im.show()
-    return im
 
 class RhythmViewer(gtk.Frame):
     def __init__(self, parent):
@@ -172,7 +78,7 @@ class RhythmViewer(gtk.Frame):
             gobject.source_remove(self.__timeout)
         self.clear()
         for x in range(self.m_num_beats):
-            self.g_box.pack_start(create_png_image('holder'), False)
+            self.g_box.pack_start(gu.create_png_image('holder'), False)
         self.m_data = []
     def clear_wrong_part(self):
         """When the user have answered the question, this method is used
@@ -189,16 +95,16 @@ class RhythmViewer(gtk.Frame):
             self.g_box.get_children()[n].destroy()
         self.m_data = self.m_data[:n]
         for x in range(n, self.m_num_beats):
-            self.g_box.pack_start(create_png_image('holder'), False)
+            self.g_box.pack_start(gu.create_png_image('holder'), False)
     def add_rhythm_element(self, i):
         assert len(self.m_data) <= self.m_num_beats
         if len(self.g_box.get_children()) >= self.m_num_beats:
             self.g_box.get_children()[self.m_num_beats-1].destroy()
         vbox = gtk.VBox()
         vbox.show()
-        im = create_rhythm_image(RHYTHMS[i])
+        im = gu.create_rhythm_image(abstract.RhythmAddOnClass.RHYTHMS[i])
         vbox.pack_start(im)
-        vbox.pack_start(create_png_image('rhythm-wrong'), False, False)
+        vbox.pack_start(gu.create_png_image('rhythm-wrong'), False, False)
         vbox.get_children()[-1].hide()
         self.g_box.pack_start(vbox, False)
         self.g_box.reorder_child(vbox, len(self.m_data))
@@ -210,7 +116,7 @@ class RhythmViewer(gtk.Frame):
                 self.g_face.destroy()
                 self.g_face = None
             self.g_box.get_children()[len(self.m_data)-1].destroy()
-            self.g_box.pack_start(create_png_image('holder'), False)
+            self.g_box.pack_start(gu.create_png_image('holder'), False)
             del self.m_data[-1]
     def mark_wrong(self, idx):
         """
@@ -266,7 +172,7 @@ class RhythmViewer(gtk.Frame):
         self.__timeout = None
         self.clear()
 
-class Gui(abstract.Gui):
+class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
     num_buttons_in_row = 8
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window)
@@ -302,36 +208,11 @@ class Gui(abstract.Gui):
         ##############
         # config_box #
         ##############
-        self.g_element_frame = frame = gtk.Frame(_("Rhythms to use in question"))
-        self.config_box.pack_start(frame, False)
-        self.g_select_rhythms_box = gu.NewLineBox()
-        self.g_select_rhythms_box.set_border_width(gu.PAD_SMALL)
-        frame.add(self.g_select_rhythms_box)
+        self.add_select_elements_gui()
         #--------    
         self.config_box.pack_start(gtk.HBox(), False,
                                    padding=gu.PAD_SMALL)
-
-        table = gtk.Table(2, 4, False)
-        self.config_box.pack_start(table, False)
-        ###
-        label = gtk.Label(_("Number of beats in question:"))
-        label.set_alignment(1.0, 0.5)
-        table.attach(label, 0, 1, 0, 1, xpadding=gu.PAD_SMALL,
-                      xoptions=gtk.FILL)
-        table.attach(gu.nSpinButton(self.m_exname, "num_beats",
-                     gtk.Adjustment(4, 1, 100, 1, 10)),
-                     1, 2, 0, 1, xoptions=gtk.FILL)
-        menu = gu.PercussionNameComboBoxEntry(self.m_exname, "rhythm_perc", "Side Stick")
-        table.attach(menu, 2, 3, 0, 1, xoptions=gtk.FILL)
-        label = gtk.Label(_("Count in before question:"))
-        label.set_alignment(1.0, 0.5)
-        table.attach(label, 0, 1, 1, 2, xpadding=gu.PAD_SMALL,
-                     xoptions=gtk.FILL)
-        table.attach(gu.nSpinButton(self.m_exname, "count_in",
-                     gtk.Adjustment(2, 0, 10, 1, 10)),
-                     1, 2, 1, 2, xoptions=gtk.FILL)
-        menu = gu.PercussionNameComboBoxEntry(self.m_exname, "countin_perc", "Claves")
-        table.attach(menu, 2, 3, 1, 2, xoptions=gtk.FILL)
+        self.add_select_num_beats_gui()
         #-----
         self.config_box.pack_start(gtk.HBox(), False,
                                    padding=gu.PAD_SMALL)
@@ -352,44 +233,18 @@ class Gui(abstract.Gui):
     def pngbutton(self, i):
         "used by the constructor"
         btn = gtk.Button()
-        if i > len(RHYTHMS):
+        if i > len(abstract.RhythmAddOnClass.RHYTHMS):
             im = gtk.Image()
             im.set_from_stock("gtk-missing-image", gtk.ICON_SIZE_LARGE_TOOLBAR)
             im.show()
             btn.add(im)
         else:
-            btn.add(create_rhythm_image(RHYTHMS[i]))
+            btn.add(gu.create_rhythm_image(abstract.RhythmAddOnClass.RHYTHMS[i]))
         btn.show()
         btn.connect('clicked', self.guess_element, i)
         return btn
-    def pngcheckbutton(self, i):
-        btn = gtk.CheckButton()
-        btn.add(create_rhythm_image(RHYTHMS[i]))
-        btn.show()
-        btn.connect('clicked', self.select_element_cb, i)
-        return btn
     def select_element_cb(self, button, element_num):
-        def sortlike(orig, b):
-            ret = []
-            for n in orig:
-                if n == 'newline':
-                    ret.append('newline')
-                elif n in b:
-                    ret.append(n)
-            return ret
-        if button.get_active():
-            if element_num not in self.m_t.m_P.header.rhythm_elements:
-                self.m_t.m_P.header.rhythm_elements.append(element_num)
-                self.m_t.m_P.header.rhythm_elements = sortlike(
-                    self.m_t.m_P.header.configurable_rhythm_elements,
-                    self.m_t.m_P.header.rhythm_elements)
-        else:
-            if element_num in self.m_t.m_P.header.rhythm_elements:
-                self.m_t.m_P.header.rhythm_elements.remove(element_num)
-        self.m_t.m_P.header.visible_rhythm_elements = \
-            self.m_t.m_P.header.rhythm_elements[:]
-        self.m_t.m_P.header.rhythm_elements = \
-            [n for n in self.m_t.m_P.header.rhythm_elements if n != 'newline']
+        super(Gui, self).select_element_cb(button, element_num)
         self.update_answer_buttons()
     def on_backspace(self, widget=None):
         if self.m_t.q_status == const.QSTATUS_SOLVED:
@@ -398,7 +253,7 @@ class Gui(abstract.Gui):
         if not self.g_rhythm_viewer.m_data:
             self.g_backspace.set_sensitive(False)
     def play_users_answer(self, widget):
-        rhythm = " ".join([RHYTHMS[c] for c in self.g_rhythm_viewer.m_data])
+        rhythm = " ".join([abstract.RhythmAddOnClass.RHYTHMS[c] for c in self.g_rhythm_viewer.m_data])
         self.m_t.play_rhythm(r"\staff{ %s }" % rhythm)
     def guess_element(self, sender, i):
         if self.m_t.q_status == const.QSTATUS_NO:
@@ -428,7 +283,7 @@ class Gui(abstract.Gui):
             self.g_backspace.set_sensitive(True)
     def new_question(self, widget=None):
         g = self.m_t.new_question()
-        if g == Teacher.OK:
+        if g == self.m_t.OK:
             self.g_first_rhythm_button.grab_focus()
             self.g_rhythm_viewer.set_num_beats(self.get_int('num_beats'))
             self.g_rhythm_viewer.create_holders()
@@ -437,26 +292,21 @@ class Gui(abstract.Gui):
             self.g_new.set_sensitive(
                not self.get_bool('config/picky_on_new_question'))
             self.m_t.play_question()
-        elif g == Teacher.ERR_PICKY:
+        elif g == self.m_t.ERR_PICKY:
             self.g_rhythm_viewer.flash(_("You have to solve this question first."))
         else:
-            assert g == Teacher.ERR_NO_ELEMS
+            assert g == self.m_t.ERR_NO_ELEMS
             self.g_repeat.set_sensitive(False)
             self.g_rhythm_viewer.flash(_("You have to configure this exercise properly"))
     def repeat_question(self, *w):
         self.m_t.play_question()
         self.g_first_rhythm_button.grab_focus()
-    def update_select_elements_buttons(self):
-        self.g_select_rhythms_box.empty()
-        for n in self.m_t.m_P.header.configurable_rhythm_elements:
-            if n == 'newline':
-                self.g_select_rhythms_box.newline()
-            else:
-                b = self.pngcheckbutton(n)
-                self.g_select_rhythms_box.add_widget(b)
-                b.set_active(n in self.m_t.m_P.header.rhythm_elements)
-        self.g_select_rhythms_box.show_widgets()
     def update_answer_buttons(self):
+        """
+        (Re)create the buttons needed to answer the questions.
+        We recreate the buttons for each lesson file because the
+        header may specify a different set of rhythm elements to use.
+        """
         self.g_answer_box.empty()
         self.g_first_rhythm_button = None
         for n in self.m_t.m_P.header.visible_rhythm_elements:
@@ -471,17 +321,7 @@ class Gui(abstract.Gui):
     def on_start_practise(self):
         assert self.m_t.m_P
         self.m_t.m_custom_mode = bool(self.m_t.m_P.header.configurable_rhythm_elements)
-        if self.m_t.m_custom_mode:
-            if not self.m_t.m_P.header.rhythm_elements:
-                self.m_t.m_P.header.rhythm_elements = self.m_t.m_P.header.configurable_rhythm_elements[:3]
-            self.m_t.m_P.header.visible_rhythm_elements = self.m_t.m_P.header.rhythm_elements[:]
-        else:
-            if not self.m_t.m_P.header.visible_rhythm_elements:
-                self.m_t.m_P.header.visible_rhythm_elements = \
-                    self.m_t.m_P.header.rhythm_elements[:]
-                self.m_t.m_P.header.rhythm_elements = \
-                  [n for n in self.m_t.m_P.header.rhythm_elements if n != 'newline']
-        #
+        self.m_t.set_elements_variables()
         self.update_answer_buttons()
         if self.m_t.m_custom_mode:
             self.update_select_elements_buttons()
@@ -492,15 +332,7 @@ class Gui(abstract.Gui):
             self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
         else:
             self.set_lesson_heading(_("Identify the rhythm"))
-        for n, default in (('bpm', 60),
-                  ('countin_perc', 80),
-                  ('count_in', 2),
-                  ('rhythm_perc', 37),
-                  ('num_beats', 4)):
-            if n in self.m_t.m_P.header:
-                self.m_t.set_int(n, self.m_t.m_P.header[n])
-            else:
-                self.m_t.set_int(n, default)
+        self.m_t.set_default_header_values()
         if 'not_start_with_rest' in self.m_t.m_P.header:
             self.m_t.set_bool('not_start_with_rest', self.m_t.m_P.header.not_start_with_rest)
         self.g_rhythm_viewer.flash(_("Click 'New' to begin."))
