@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ class Teacher(abstract.Teacher):
         self.play_question()
     def play_440hz(self):
         soundcard.play_note(self.get_int('config/preferred_instrument'),
-                       4, 0, mpd.notename_to_int("a'"),
+                       4, mpd.notename_to_int("a'"),
                        self.get_int('config/preferred_instrument_velocity'))
 
 class Gui(abstract.LessonbasedGui):
