@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,13 +38,13 @@ class Teacher(abstract.Teacher):
         if self.q_status == const.QSTATUS_NO:
             return
         soundcard.play_note(self.get_int('config/preferred_instrument'),
-                        4, 0, mpd.notename_to_int(self.m_question[0]),
+                        4, mpd.notename_to_int(self.m_question[0]),
                         self.get_int('config/preferred_instrument_velocity'))
     def play_last_note(self):
         if self.q_status == const.QSTATUS_NO:
             return
         soundcard.play_note(self.get_int('config/preferred_instrument'),
-                        4, 0, mpd.notename_to_int(self.m_question[-1]),
+                        4, mpd.notename_to_int(self.m_question[-1]),
                         self.get_int('config/preferred_instrument_velocity'))
     def play_all_notes(self):
         if self.q_status == const.QSTATUS_NO:
@@ -54,7 +54,7 @@ class Teacher(abstract.Teacher):
             s = s + " " + n
         s = s + "}"
         track = mpd.music_to_track(s, self.get_int('config/preferred_instrument_velocity'))
-        track.prepend_patch(0, self.get_int('config/preferred_instrument'))
+        track.prepend_patch(self.get_int('config/preferred_instrument'))
         soundcard.synth.play_track(track)
 
 class Gui(abstract.Gui):
