@@ -1,5 +1,5 @@
-# GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ def mangle_email(email):
 
 def play_tone(midi_int):
     soundcard.play_note(cfg.get_int('config/preferred_instrument'),
-                        4, 0, midi_int,
+                        4, midi_int,
                         cfg.get_int('config/preferred_instrument_velocity'))
 
 def int_to_intervalname(i, shortname=None, updown=None):
