@@ -1,4 +1,4 @@
-#!/usr/bin/python2.3
+#!/usr/bin/python
 
 import pygtk
 pygtk.require("2.0")
@@ -79,7 +79,8 @@ class DisplaytestWindow(gtk.Window):
 
 #soundcard.initialise_devicefile("/dev/sequencer", 0)
 #soundcard.initialise_devicefile("/dev/music", 0)
-soundcard.initialise_using_fake_synth()
+#soundcard.initialise_using_fake_synth()
+soundcard.initialise_external_midiplayer("/usr/bin/timidity %s")
 
 w = DisplaytestWindow()
 w.connect('destroy', gtk.main_quit)
